@@ -21,7 +21,7 @@ import sys
 from datetime import timedelta
 from typing import Any, List, Optional, Tuple, Type, Union
 
-from hspylib.core.tools.constants import TRUE_VALUES
+from hspylib.core.constants import TRUE_VALUES
 from hspylib.core.tools.validator import Validator
 from hspylib.modules.cli.vt100.vt_codes import VtCodes
 from hspylib.modules.cli.vt100.vt_colors import VtColors
